==> v1.41.0.zip: compose-lobsters/README.md <==
# Claw for [lobste.rs](https://lobste.rs) [![CI](https://github.com/msfjarvis/compose-lobsters/actions/workflows/ci.yml/badge.svg)](https://github.com/msfjarvis/compose-lobsters/actions/workflows/ci.yml)

Unofficial Android app for read-only access to [lobste.rs](https://lobste.rs), built with [Jetpack Compose](https://developer.android.com/jetpack/compose).

<a href="https://play.google.com/store/apps/details?id=dev.msfjarvis.claw.android">
  <img src="https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png"
       alt="Get it on Google Play"
       height="80" />
</a>

> [!NOTE]
> Snapshots from the development branch can be obtained [here](https://github.com/msfjarvis/compose-lobsters/releases/tag/latest).
>
> They are also published in the Google Play 'Open Testing' channel, which can be opted into via this link: [[Android]](https://play.google.com/store/apps/details?id=dev.msfjarvis.claw.android) [[Web]](https://play.google.com/apps/testing/dev.msfjarvis.claw.android)

<img src="https://github.com/msfjarvis/compose-lobsters/blob/main/.github/readme_feature_light.webp#gh-light-mode-only"
     alt="A grid of screenshots from the app, in clockwise order: the main screen, the comments page, the search page and the saved posts page"
     width="550" />

<img src="https://github.com/msfjarvis/compose-lobsters/blob/main/.github/readme_feature_dark.webp#gh-dark-mode-only"
     alt="A grid of screenshots from the app, in clockwise order: the main screen, the comments page, the search page and the saved posts page"
     width="550" />

## License

See [LICENSE](LICENSE)

==> v1.43.0.zip: compose-lobsters/README.md <==
# Claw for [lobste.rs](https://lobste.rs) [![CI](https://github.com/msfjarvis/compose-lobsters/actions/workflows/ci.yml/badge.svg)](https://github.com/msfjarvis/compose-lobsters/actions/workflows/ci.yml)

Unofficial Android app for read-only access to [lobste.rs](https://lobste.rs), built with [Jetpack Compose](https://developer.android.com/jetpack/compose).

<a href="https://play.google.com/store/apps/details?id=dev.msfjarvis.claw.android">
  <img src="https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png"
       alt="Get it on Google Play"
       height="80" />
</a>

> [!NOTE]
> Daily builds are published to the Google Play 'Open Testing' channel (if there are any changes), which can be opted into via this link: [[Android]](https://play.google.com/store/apps/details?id=dev.msfjarvis.claw.android) [[Web]](https://play.google.com/apps/testing/dev.msfjarvis.claw.android)

<img src="https://github.com/msfjarvis/compose-lobsters/blob/main/.github/readme_feature_light.webp#gh-light-mode-only"
     alt="A grid of screenshots from the app, in clockwise order: the main screen, the comments page, the search page and the saved posts page"
     width="550" />

<img src="https://github.com/msfjarvis/compose-lobsters/blob/main/.github/readme_feature_dark.webp#gh-dark-mode-only"
     alt="A grid of screenshots from the app, in clockwise order: the main screen, the comments page, the search page and the saved posts page"
     width="550" />

## License

See [LICENSE](LICENSE)
